@@ -62,11 +62,18 @@ hplm <- function(data, dvar, pvar, mvar,
                  data.l2 = NULL, 
                  ...) {
 
+  .start_check() %>%
+    .check_in(model, c("H-M", "B&L-B", "JW", "JW2")) %>%
+    .end_check()
+  
   # set attributes to arguments else set to defaults of scdf
-  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv) else scdf_attr(data, .opt$dv) <- dvar
-  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) else scdf_attr(data, .opt$phase) <- pvar
-  if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) else scdf_attr(data, .opt$mt) <- mvar
-
+  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv)
+  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) 
+  if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) 
+  scdf_attr(data, .opt$dv) <- dvar
+  scdf_attr(data, .opt$phase) <- pvar
+  scdf_attr(data, .opt$mt) <- mvar
+  
   dat <- .prepare_scdf(data)
   
   N <- length(dat)
