@@ -34,7 +34,7 @@ pet <- function(data, dvar, pvar, mvar, ci = 0.95, decreasing = FALSE, phases =
   if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) else scdf_attr(data, .opt$mt) <- mvar
   
   data <- .prepare_scdf(data, na.rm = TRUE)
-  data <- .keep_phases(data, phases = phases, pvar = pvar)$data
+  data <- .keep_phases(data, phases = phases)$data
   
   N <- length(data)
   
