@@ -8,11 +8,11 @@
 #'
 #' @return An scdf with selected phases
 #' @examples 
-#' exampleA1B1A2B2 %>% 
+#' exampleA1B1A2B2_zvt %>% 
 #'   select_phases(A = c(1, 3), B = c(2, 4)) %>%
 #'   overlap()
 #' @export
-select_phases <- function(data, A, B, ...) {
+select_phases <- function(data, A, B) {
   data <- .prepare_scdf(data)
   keep <- .keep_phases(data, phases = list(A = A, B = B))
   data <- keep$data
